# Linear Algebra

[TOC]

## Definitions

### Vector operations

Basic operations\cite{asness2014quality} on vectors are: addition, subtraction, scaling, norm (length), dot product, and cross product:

$$ \vec{u} + \vec{v} = (u_{1} + v_{1}, u_{2} + v_{2}, u_{3} + v_{3}) $$

$$ \vec{u} - \vec{v} = (u_{1} - v_{1}, u_{2} - v_{2}, u_{3} - v_{3}) $$

$$ \alpha \vec{u} = (\alpha u_{1}, \alpha u_{2}, \alpha u_{3}) $$

$$ \left\| \vec{u} \right\| = \sqrt{u^{2}_{1} +u^{2}_{2} + u^{2}_{3} }  $$

$$ \vec{u} \cdot \vec{v} = u_{1} v_{1} + u_{2} v_{2} + u_{3} v_{3}= \left\|\vec{u}\right\| \left\|\vec{v}\right\|\cos \theta   $$

Dot product/inner product is the product of "length" of vectors going "same direction".

$$ \vec{u} \times  \vec{v} = (u_{2}v_{3} - u_{3} v_{2}, u_{3} v_{1} - u_{1} v_{3}, u_{1} v_{2} - u_{2} v_{1}) $$

$ \left\|\vec{u}\times \vec{v}\right\| = \left\|\vec{u}\right\| \left\|\vec{v}\right\|\sin \theta   $ 

Cross product is only defined in $R^3$. The result of cross product is a new vector which is orthogonal to the original two vectors. The cross product is also the area of the two vectors, so that when these two are orthogonal to each other the maxium the area, in the same time the minimium the dot product.

The dot product can also be expressed in trigonometric, as $ \vec{u} \cdot \vec{v} = \left\|\vec{u} \right\| \left\|\vec{v} \right\| \cos \theta $. When the two vectors are said to be *orthogonal*, the $\cos$ is zero then the dot product is zero as well. The cross product is given by $ \left\|\vec{u} \times  \vec{v}\right\| = \left\|\vec{u} \right\| \left\|\vec{v} \right\| \sin \theta $. It is not commutative, which means the order of multiple matters. $\vec{u} \times  \vec{v}\ = -\vec{v} \times \vec{u}$ instead. 

>  $ \left\|\vec{x}\right\|^2= \vec{x} \cdot \vec{x} $ 

#### Inequality

> triangle inequality: $\left\| \vec{x} + \vec{y}\right\| \leq \left\|\vec{x}\right\| +\left\|\vec{y}\right\| $ 



> Cauchy-Schwarz inequality: $ \left\|\vec{x}\right\| \left\|\vec{y}\right\| \geq \left|\vec{x}\cdot \vec{y}\right|  \geq \vec{x} \cdot \vec{y}$ 

### Matrix operations

Only include the operations that I might forget.

- matrix inverse ($ A^{-1}$)

- matrix trace ($ Tr\left[A\right] \equiv \sum\limits_{i=1}^{n}{a_{ii} } $)

- determinant ($\left|A\right| $ or $det(A)$)

  The matrix product is not commutative either. $AB \neq BA$.

  ?

> $A \vec{x} = \vec{b}$
>
> columns of $\vec{b}$ is the linear combination of columns of $A$

### Matrix-vector product

![Alt text](http://i.imgur.com/8c2hQOF.png)



----

## Notes of Khan Academy

### Vectors

$R^2$ is the two dimensional real coordinate space, which contains all possible real valued 2-tuple. $R^n$ is the n dimensional real coordinate space.

Parametric representations of line: $L=\left\{\vec{x}+t\vec{v} \mid t \in  R \right\}$. It is the general form of line.

#### Linear combinations

If $\vec{a}$ and $\vec{b}$ are not co-linear, then the $span(\vec{a},\vec{b}) = R^2$.

A set of vectors $S=\left\{\vec{v_1}, \vec{v_2}, \vec{v_3},...\vec{v_n}, \right\}$ is linear dependent, iff $c_i$ could satisfy the equation $ c_1\vec{v_1} + c_2\vec{v_2} +c_3\vec{v_3}+... c_n\vec{v_n}=\vec{0}$ for some $c_i$ not all are zero, or put it another way, at least 1 $c_i$ is non-zero. And if the only solution to satisfy the equation is that all $c_i$ has to be zero, then the set of vectors are *linear independent*.

The subspace of $R^n$: say $V$ is subset of $R^n$, for $V$ to be subspace of $R^n$, three conditions must be satisfied:

1. contains $\vec{0}$

2. closure under scalar multiplication

3. closure under addition

It represents all the linear combinations of the vectors in a span, $V=span\left\{c_1\vec{v_1} + c_2\vec{v_2} +c_3\vec{v_3}+... c_n\vec{v_n} \mid c_i=R\right\}$. If all the vectors in a span are linearly independent, then it is called a basis of the subspace. The basis of a subspace is the *minimium* set of vectors that spans the whole subspace. And each member of the subspace can only be represented by an unique combination of the basis.

#### Vector dot and cross products

 $ \left\|\vec{x}\right\|^2= \vec{x} \cdot \vec{x} $ 

triangle inequality: $\left\| \vec{x} + \vec{y}\right\| \leq \left\|\vec{x}\right\| +\left\|\vec{y}\right\| $ 

Cauchy-Schwarz inequality: $ \left\|\vec{x}\right\| \left\|\vec{y}\right\| \geq \left|\vec{x}\cdot \vec{y}\right|  \geq \vec{x} \cdot \vec{y}$ 

### Null space and column space

The **null space** of $A$ is the subspace $N=\left\{\vec{x} \in R^n \mid A\vec{x}=\vec{0}\right\}$. 

The **column space** of $A$ is all the linear combinations of its column vectors. It is the span of its column vectors.

>  Definition 1: $\underset{m\times n}{A} =\left[\vec{v_1}, \vec{v_2},...,\vec{v_n}\right] $, which $\vec{v_1}, \vec{v_2},...,\vec{v_n} \in R^m$ $
>
>  C(A)=span(\vec{v_1},\vec{v_2},...,\vec{v_n})$

The column space of $A$ can also be viewed on another perspective.

>  Definition 2: $\left\{A\vec{x} \mid \vec{x} \in R^n\right\} $

The **basis** of column space is the span of columns that associate only with the pivot entries in Reduced Row-Echelon Form. If the columns are linear independent, then the basis is the whole column vectors.

The **dimension** of $V$ is the number of elements in a basis of $V$. Any subspace basis has same number of elements. The dimension of the null space or **nullity** is the number of non-pivot columns in $rref(A)$. The dimension of column space (also called **rank**) is the number of pivot columns.

### Functions and Linear transformations

The transformation is the function operation on vectors. Matrix product with vectors is always linear transformation. Any linear transformation can be represented by product of matrices. 

